variable "chart_name" {
  description = "Name of the Helm chart"
  type = string
}

variable "chart_repo" {
  description = "URL of the Helm chart repository"
  type = string
}

variable "chart_version" {
  description = "Version of the Helm chart"
  type = string
}

variable "release_name" {
  description = "Name of the Helm release"
  type = string
}

variable "namespace" {
  description = "Kubernetes namespace for the release"
  type = string
}

variable "create_namespace" {
    description = "Create Kubernetes namespace if it doesn't exist"
    type = bool
    default = true
}

variable "recreate_pods" {
  description = "Ensures that pods are restarted during an upgrade or rollback of the release"
  type = bool
  default = false
}

variable "dependency_update" {
  description = "This option runs `helm dependency update` before installing the chart"
  type = bool
  default = false
}

variable "force_update" {
  description = "Forces the resource to update through delete and recreate if necessary"
  type = bool
  default = true
}

variable "wait" {
    description = "Wait for the Helm chart to be applied"
    type = bool
    default = true
}

variable "default_values_files" {
  description = "Custom values files for the Helm chart"
  type = list(string)
  default = []
}

variable "extra_values_files" {
  description = "Custom values files for the Helm chart"
  type = list(string)
  default = []
}

variable "default_set_values" {
  description = "Map of values to set"
  type = map(string)
  default = {}
}

variable "extra_set_values" {
  description = "Map of values to set"
  type = map(string)
  default = {}
}

variable "default_set_sensitive_values" {
  description = "Map of sensitive values to set"
  type = map(string)
  default = {}
}

variable "extra_set_sensitive_values" {
  description = "Map of sensitive values to set"
  type = map(string)
  default = {}
}

locals {
  values_files = concat(var.default_values_files, var.extra_values_files)
  values_content = [for file_path in local.values_files : file(file_path)]

  set_values = merge(var.default_set_values, var.extra_set_values)
  set_sensitive_values = merge(var.default_set_sensitive_values, var.extra_set_sensitive_values)
}
